@@ -25,23 +25,34 @@ class AbstractLogger(ABC):
 
 
 class LoggingLogger(AbstractLogger):
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, module_name=None, **kwargs) -> None:
         logging.basicConfig(
             format="[%(asctime)s][%(levelname)s]: %(message)s",
             level=logging.INFO if not kwargs.get("debug") else logging.DEBUG,
         )
+        self.module_name = module_name
 
     def info(self, msg):
+        if self.module_name is not None:
+            msg = " ".join([self.module_name, msg])
         return logging.info(msg)
 
     def error(self, msg):
+        if self.module_name is not None:
+            msg = " ".join([self.module_name, msg])
         return logging.error(msg)
 
     def debug(self, msg):
+        if self.module_name is not None:
+            msg = " ".join([self.module_name, msg])
         return logging.debug(msg)
 
     def warn(self, msg):
+        if self.module_name is not None:
+            msg = " ".join([self.module_name, msg])
         return logging.warn(msg)
 
     def exception(self, msg):
+        if self.module_name is not None:
+            msg = " ".join([self.module_name, msg])
         return logging.exception(msg)
\ No newline at end of file
